# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session History Service."""

__version__ = "1.9.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .query_acquiring_ds import QueryAcquiringDS
from .query_acquiring_ds_wait_a2982b import QueryAcquiringDSWaitTimeAvg
from .query_detail_tick_match_pool import QueryDetailTickMatchPool
from .query_detail_tick_match_f9b8b2 import QueryDetailTickMatchPoolMatches
from .query_detail_tick_match_d45948 import QueryDetailTickMatchPoolTicket
from .query_match_histories import QueryMatchHistories
from .query_match_length_durationp99 import QueryMatchLengthDurationp99
from .query_match_length_dura_0e6d44 import QueryMatchLengthDurationpAvg
from .query_match_ticket_histories import QueryMatchTicketHistories
from .query_total_active_session import QueryTotalActiveSession
from .query_total_matchmaking_49d09d import QueryTotalMatchmakingCanceled
from .query_total_matchmaking_73a209 import QueryTotalMatchmakingCreated
from .query_total_matchmaking_adaa30 import QueryTotalMatchmakingExpired
from .query_total_matchmaking_match import QueryTotalMatchmakingMatch
from .query_total_matchmaking_0ba5f3 import QueryTotalMatchmakingMatchTicket
from .query_total_player_persession import QueryTotalPlayerPersession
from .query_xray_match import QueryXrayMatch
from .query_xray_match_pool import QueryXrayMatchPool
from .query_xray_timeline_by__b9129e import QueryXrayTimelineByTicketID
from .query_xray_timeline_by_user_id import QueryXrayTimelineByUserID
